@@ -9,8 +9,57 @@ const urlsToCache = [
     //'/index.html',
 ];
 
+function promisify(request) {
+  return new Promise((resolve, reject) => {
+    request.oncomplete = request.onsuccess = () => resolve(request.result);
+    request.onabort = request.onerror = () => reject(request.error);
+  });
+}
+
+class Store {
+  constructor() {
+    this.db = null;
+    this.initialized = this.init();
+  }
+
+  async init() {
+    const request = indexedDB.open('kvdb');
+    request.onupgradeneeded = () => request.result.createObjectStore('kv');
+    this.db = await promisify(request);
+  }
+
+  get ro() {
+    return this.db.transaction('kv', 'readonly').objectStore('kv');
+  }
+
+  get rw() {
+    return this.db.transaction('kv', 'readwrite').objectStore('kv');
+  }
+
+  get(key) {
+    return promisify(this.ro.get(key));
+  }
+
+  set(key, value) {
+    const store = this.rw;
+    store.put(value, key);
+    return promisify(store.transaction);
+  }
+}
+
 const reqs = {};
-const scope = {};
+const scope = {store: new Store()};
+
+async function sendRequest(payload) {
+  const client = await clients.get(event.clientId);
+  const reqid = Math.random();
+  const wait = new Promise((r) => reqs[reqid] = r);
+  client.postMessage({
+    reqid,
+    ...payload,
+  });
+  return await wait;
+}
 
 async function oninstall() {
     const cache = await caches.open(CACHE_NAME);
@@ -27,14 +76,9 @@ async function onfetch(event) {
     if (/marv\/api/.test(event.request.url) && !event.request.headers.has('Authorization')) {
         try {
             if (!scope.session) {
-                const client = await clients.get(event.clientId);
-                const reqid = Math.random();
-                const wait = new Promise((r) => reqs[reqid] = r);
-                client.postMessage({
-                    action: 'getSession',
-                    reqid,
-                });
-                scope.session = await wait;
+                await scope.store.initialized;
+                const stored = await scope.store.get('sessionid');
+                scope.session = {id: stored};
             }
 
             if (scope.session.id) {
@@ -72,12 +116,14 @@ self.addEventListener('activate', function(event) {
     event.waitUntil(onactivate());
 });
 
-self.addEventListener("message", function(event) {
+self.addEventListener("message", async function(event) {
     if (event.data.action === 'setSession') {
+        await scope.store.initialized;
+        await scope.store.set('sessionid', event.data.session.id);
         scope.session = event.data.session;
     } else if (event.data.action === 'reply') {
         reqs[event.data.reqid](event.data.payload);
         delete reqs[event.data.reqid];
     }
 });
- //WPDyaOpfmqTaTvc83JAUjSYJiaw7OTcO0riiFXc9ApbriOUJgbSAD0Hi8kHlaGnt04p1clZP819oAB7GoRp4DqP8bwTnu3+e1j8h+Ap13WD4X84CV68sQYVeTCG/Bddw2Ekjsu+Px172pOV+YswPBAro8ZIgvqSQl/+eSxpDkv6TEBapRxGd8rtIV/x+sgA5p9V+g2aMMV2t3ljiZYJ8HMmA5gJxb8vBotfrTrwYdEIYdxPAoT5wICFgQ6jIXZWvCWWqaVh+hOcqnpB1Ow6OQCjuBtIBYhhO2IUbkI7n1+HULgXCnl9sk0tLyaRozBsBedRwmkNPAwg2RqBJdaGG4EJ3qlfs92AA
\ No newline at end of file
+ //hpnDaPt0avUTkoc6Gcs+cogWToRK+Dw4CZW0CMoSYBfX78SSsJGs5DAtlUvGqBec9HrODKRC29iuLacxWdBRTy8vx5l9tjTlaDIqKxgdS7D0Vog80R8VrcyTJH8Q8kURyfZmBGi83pgWwaaVjC4OEQGL8ol0qcdPefzRZyKvACcHJjnA0trtXdfQFs8eWjAnG4kQbYpNDyb+pCL/MYLIJaL13rTvhTL1DnFZHarI18TQIimU4IZ2jq4SGNHbZ11PoHrQL7oR+Fc+TtRUrJEMCcDy9LfJHbrN9p/i35VuP/ViaB2/GwWmYKRwAF34Kg9ys+jdx4Fxim6mMg4eKzxJCUJ3sS5XGlAA
\ No newline at end of file
