@@ -14,6 +14,7 @@ from contextlib import asynccontextmanager
 from functools import reduce
 from logging import getLogger
 from pathlib import Path
+from runpy import run_path
 
 import click
 from aiohttp import web
@@ -36,10 +37,14 @@ from marv_store import DirectoryAlreadyExists
 
 try:
     import marv_ee
-    from marv_ee.app import App
-    from marv_ee.site import Site
 except ImportError:
     marv_ee = None
+
+if marv_ee:
+    marv_ee.init()
+    from marv_ee.app import App  # pylint: disable=import-error
+    from marv_ee.site import Site  # pylint: disable=import-error
+else:
     from marv.app import App
     from marv.site import Site
 
@@ -199,6 +204,8 @@ def marvcli_develop_server(port, public):
 def marvcli_serve(host, port, certfile, keyfile, approot):
     """Run webserver through gunicorn."""
     config = get_site_config()
+    if within_pyinstaller_bundle():
+        ensure_python(config, '')
 
     async def app_factory():
         """App factory used inside of worker.
@@ -921,5 +928,9 @@ def marvcli_python(unbuffered, ignore, command, args):  # pylint: disable=unused
         sys.argv = ['-c', *args]
         sys.path.append('.')
         exec(compile(command, 'python_wrapper', 'exec'))  # pylint: disable=exec-used
+    elif args:
+        sys.argv = [*args]
+        sys.path.append('.')
+        run_path(args[0], run_name='__main__')
     else:
         code.interact(local=locals())
