@@ -3,6 +3,7 @@
 
 """Marv config parsing."""
 
+import os
 import sys
 import sysconfig
 from configparser import ConfigParser
@@ -13,7 +14,7 @@ from pathlib import Path
 from typing import Any, Dict, Optional, Tuple
 
 from pkg_resources import resource_filename
-from pydantic import BaseModel, Extra, ValidationError, validator
+from pydantic import BaseModel, Extra, ValidationError, root_validator, validator
 
 from marv_api.utils import echo
 
@@ -96,9 +97,13 @@ def detail_route(setid, name=None):
 
 
 def doget(value, name, lookup):
-    value = getattr(value, name, None)
+    if isinstance(value, dict):
+        value = value.get(name, None)
+    else:
+        value = getattr(value, name, None)
     if value is None:
         return None
+
     if lookup is not None:
         try:
             return value[lookup]
@@ -220,6 +225,12 @@ def split(val):
     return []
 
 
+def splitcommastrip(val):
+    if val is not None:
+        return [x.strip() for x in val.split(',')]
+    return []
+
+
 def splitlines(val):
     if val is not None:
         return [stripped for x in val.splitlines() if (stripped := x.strip())]
@@ -263,8 +274,11 @@ class MarvConfig(Model):
     dburi: str = 'sqlite://db/db.sqlite'
     frontenddir: Path = 'frontend'
     leavesdir: Path = 'leaves'
+    leafbinpath: Optional[Path] = None
     mail_footer: str = ''
     oauth: Dict[str, Tuple[str, ...]] = None
+    oauth_enforce_username: Optional[str] = None
+    oauth_gitlab_groups: Optional[Tuple[str, ...]] = None
     reverse_proxy: Optional[ReverseProxyEnum] = None
     resourcedir: Path = 'resources'
     sessionkey_file: Path = 'sessionkey'
@@ -279,6 +293,7 @@ class MarvConfig(Model):
     def sitepackages(self):
         return self.venv / 'lib' / f'python{sysconfig.get_python_version()}' / 'site-packages'
 
+    _oauth_gitlab_groups = reapvalidator('oauth_gitlab_groups')(splitcommastrip)
     _resolve_path = reapvalidator('sitedir')(resolve_path)
     _resolve_relto_site = reapvalidator('frontenddir', 'leavesdir', 'resourcedir',
                                         'sessionkey_file', 'staticdir', 'storedir',
@@ -305,6 +320,22 @@ class MarvConfig(Model):
             }
         return {}
 
+    @root_validator(pre=True)
+    def root_validator(cls, values):
+        if values.get('oauth_enforce_username') and len(values.get('oauth')) != 1:
+            raise ValueError('Use oauth_enforce_username with exactly one oauth provider.')
+        if val := os.environ.get('MARV_LEAVES_PATH'):
+            values['leavesdir'] = val
+        if val := os.environ.get('MARV_REVERSE_PROXY'):
+            values['reverse_proxy'] = val
+        if val := os.environ.get('MARV_VENV_PATH'):
+            values['venv'] = val
+        if val := os.environ.get('MARV_LEAFBIN_PATH'):
+            values['leafbinpath'] = val
+        else:
+            values['leafbinpath'] = values['sitedir']
+        return values
+
 
 ParsedSexp = Tuple[str, Tuple[Any, ...]]
 
